#
# spec file for package recode
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         libname lib%{name}3
Name:           recode
Version:        3.7.14
Release:        1.1
Summary:        Character Set Converter
License:        GPL-3.0-or-later AND LGPL-2.1-or-later
Group:          Productivity/Text/Convertors
URL:            https://github.com/rrthomas/recode
Source:         %{url}/releases/download/v%{version}/%{name}-%{version}.tar.gz
BuildRequires:  flex
BuildRequires:  help2man
BuildRequires:  python3
BuildRequires:  python3-Cython
BuildRequires:  python3-setuptools

%description
Recode converts files between various character sets.
It supports conversion to and from HTML entities as well.

%package      devel
Summary:        Character Set Converter
License:        LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}

%description  devel
Recode converts files between various character sets.

%package -n %{libname}
Summary:        Recode shared library
License:        GPL-3.0-or-later AND LGPL-2.1-or-later
Group:          System/Libraries

%description -n %{libname}
Recode converts files between various character sets.

This package contains librecode shared library for embedding in
other applications.

%prep
%autosetup -p1

%build
%configure --disable-static
%make_build

%check
%make_build check

%install
%make_install
rm -f %{buildroot}%{_libdir}/librecode.la
%find_lang %{name}

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -f %{name}.lang
%license COPYING COPYING-LIB
%doc ABOUT-NLS AUTHORS NEWS README THANKS TODO ChangeLog
%{_mandir}/man1/*
%{_infodir}/recode*
%{_bindir}/recode

%files devel
%license COPYING COPYING-LIB
%{_includedir}/*.h
%{_libdir}/librecode.so

%files -n %{libname}
%license COPYING COPYING-LIB
%{_libdir}/librecode.so.*

%changelog
* Mon Mar 13 2023 Dirk Müller <dmueller@suse.com>
- update to 3.7.14:
  * No user-visible changes; minor clean-ups as part of the
    Debian packaging process.
  * switch to setuptools
* Mon Jan 30 2023 Andreas Vetter <vetter@physik.uni-wuerzburg.de>
- update to 3.7.13:
  * Fix request diagnostics with --verbose: avoid output of confusing and
    possibly incorrect diagnostics.
  * Fix a file descriptor leak.
* Thu Feb 17 2022 Andreas Stieger <andreas.stieger@gmx.de>
- update to 3.7.12:
  * Simplify support for ignoring invalid input with iconv,
    integrated with the --strict and --force mechanisms
- drop obsolete texinfo packaging macros
- fix devel package dependency warning and package license texts
* Fri Feb  4 2022 Dirk Müller <dmueller@suse.com>
- udpate to 3.7.11:
  * Re-add support for transliteration with iconv (removed in 3.7).
  * Add support for ignoring invalid input with iconv.
  * Fix a bug introduced in 3.7.10 that prevented building the code.
* Sun Jan 23 2022 Dirk Müller <dmueller@suse.com>
- udpate to 3.7.10:
  * In recode program, only use iconv if needed; add --prefer-iconv option to
    allow its use in all cases.
  * Remove support for pre-3.5 request syntax (colon as charset separator).
  * PO files have been updated from the Translation Project.
  * Build system fixes and improvements.
  * Update gnulib to fix a problem building on Android.
  * Fix confusingly wrong NEWS entry for 3.7.4.
* Sat Jul  3 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 3.7.9
  + Fix CP1252 encoding: U+017E LATIN SMALL LETTER Z WITH CARON is
    at byte 0x9e, not byte 0x8f.
  + Minor documentation fixes.
* Wed Dec 16 2020 Andreas Vetter <vetter@physik.uni-wuerzburg.de>
- Update to 3.7.8
  + Improvements to the build system.
  + Fix man page generation, and document that help2man must be built with
    gettext.
  + Updates to nl, pt, sv translations (thanks, translators!).
* Sat Aug 15 2020 Dirk Mueller <dmueller@suse.com>
- update to 3.7.7
  + Improvements to the build system.
  + Updates to nl, pt, sv translations (thanks, translators!).
* Mon May 25 2020 Andreas Vetter <vetter@physik.uni-wuerzburg.de>
- reflect version of shared library in package name: librecode3
* Thu May 21 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.7.6:
  * Improvements to the build system.
- Changes from version 3.7.5:
  * Port tests to Python 3.
- Changes from version 3.7.4:
  * Fixes to file handling in enchant program.
  * Fix tests on Windows.
- Changes from version 3.7.3:
  * No code changes to recode itself; this release features a
    properly versioned shared library.
- Changes from version 3.7.2:
  * No code changes to recode itself; this release includes updates
    to license headers to guide users to the GPL online, corrects
    the version of COPYING-LIB shipped with the sources, and
    updates the message files for various languages.
- Replace python and python-Cython for their py3 variants following
  upstreams port.
* Mon Mar 18 2019 Jan Engelhardt <jengelh@inai.de>
- Remove --with-pic (useless in the face of --disable-static).
- Proper Group: tag for librecode.
* Fri Mar  8 2019 Andreas Vetter <vetter@physik.uni-wuerzburg.de>
- remove unrecognized options from configure: --without-included-gettext
* Fri Mar  8 2019 Andreas Vetter <vetter@physik.uni-wuerzburg.de>
- clean up spec according spec-cleaner
* Fri Mar  8 2019 Andreas Vetter <vetter@physik.uni-wuerzburg.de>
- use preun for install_info_delete
* Thu Mar  7 2019 Andreas Vetter <vetter@physik.uni-wuerzburg.de>
- split out shared library
- use spec-cleaner
* Sat Feb 23 2019 Andreas Vetter <vetter@physik.uni-wuerzburg.de>
- use "%%license COPYING COPYING-LIB"
- remove the %%defattr lines
* Tue Jan 29 2019 vetter@physik.uni-wuerzburg.de
- update to version 3.7.1 from https://github.com/rrthomas/recode
* Wed Mar  6 2013 seife+obs@b1-systems.com
- fix build with automake 1.13.1
* Fri Feb  1 2013 coolo@suse.com
- update license to new format
* Wed Jun  6 2012 meissner@suse.de
- fix build with new automake
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Thu Dec 15 2011 aj@suse.de
- Fix source URL.
* Wed Nov 23 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Thu Dec 30 2010 vcizek@novell.com
- fix for segfault bnc#503437
- see comment in the patch file
* Sun Oct 31 2010 jengelh@medozas.de
- Use %%_smp_mflags
* Fri Mar  5 2010 puzel@novell.com
- add recode-3.6-fix-flex-m4.patch - fix build
  - see comment in the patch
* Sat Dec 19 2009 jengelh@medozas.de
- add baselibs.conf as a source
* Tue Nov  3 2009 coolo@novell.com
- updated patches to apply with fuzz=0
* Wed Jan  7 2009 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Tue Nov 11 2008 ro@suse.de
- SLE-11 uses PPC64 instead of PPC, adapt baselibs.conf
* Wed Sep  3 2008 crrodriguez@suse.de
- disable static libraries
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Wed Mar 12 2008 schwab@suse.de
- Fix memory leak.
* Thu Feb 21 2008 crrodriguez@suse.de
- remove librecode.la that has empty dependency_libs
- use find_lang macro
* Tue Oct 23 2007 meissner@suse.de
- fixed gcc 4.3 problem
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Apr 12 2005 ro@suse.de
- fix build with current gettext
* Sat Jan 10 2004 adrian@suse.de
- add %%defattr
* Thu Apr 24 2003 ro@suse.de
- fix install_info --delete call and move from preun to postun
* Thu Feb 13 2003 mmj@suse.de
- Use %%install_info macro [#23453]
* Fri Aug 30 2002 pmladek@suse.cz
- fixed dependency of the devel subpackage on the main package (used %%version)
- aplied Debian's patch which fixes recode_buffer_to_buffer which failed
  for certain 1-step recodes [#11503]
* Sun Jul 28 2002 kukuk@suse.de
- remove unused diffutils from neededforbuild
* Fri Mar 29 2002 pmladek@suse.cz
- fixed to compile with autoconf-2.53
* Tue Feb  5 2002 rvasice@suse.cz
- fix locale bug #12817
* Fri Jan 11 2002 schwab@suse.de
- Use gettext from libc.
* Mon Oct  8 2001 schwab@suse.de
- Fix infinite loop in iconv wrapper.
- Reenable testsuite on all architectures.
* Mon Oct  8 2001 schwab@suse.de
- Fix bounds computation in guarantee_nul_terminator.
* Tue Jul  3 2001 ro@suse.de
- don't call make check for other archs
* Tue Jul  3 2001 olh@suse.de
- dont call make check on ppc, it eats your disk space
* Mon Jul  2 2001 cihlar@suse.cz
- update to version 3.6
- clean up spec file
* Mon Jun 18 2001 schwab@suse.de
- Call aclocal to get new libtool macros.
- Fix missing return value.
* Mon Jun 11 2001 pblaha@suse.cz
- add libtoolize --force for build
* Wed May  9 2001 mfabian@suse.de
- bzip2 sources
* Mon Apr 23 2001 pblaha@suse.cz
- fix compilation on axp
- fix name for catalog messages  *.mo
* Mon Mar  5 2001 pblaha@suse.cz
- move info back from recode-devel -> recode
* Wed Dec  6 2000 schwab@suse.de
- Add %%suse_update_config.
* Tue Dec  5 2000 uli@suse.de
- added diffutils to neededforbuild
* Tue Nov 21 2000 kukuk@suse.de
- Use macros to support multilib plattforms
* Mon Nov 20 2000 pblaha@suse.cz
- moved .so link to devel
* Mon Nov 13 2000 pblaha@suse.cz
- split to devel and created czech locales
* Mon Jul 24 2000 schwab@suse.de
- Fix even more memory leaks.
* Wed Jul 12 2000 bubnikv@suse.cz
- Fix more memory leaks (patch from Christian.Lorenz@suse.de).
* Mon Apr  3 2000 schwab@suse.de
- Fix more memory leaks.
* Mon Mar 13 2000 schwab@suse.de
- Fix some memory leaks.
* Wed Mar  1 2000 ke@suse.de
- add patch to improve lat1..texi.
* Mon Feb 21 2000 ro@suse.de
- include the shared recode-lib (since the binary is linked against it)
* Sun Feb 20 2000 ke@suse.de
- general spec file cleanup:
- get rid of Makefile.Linux.
- add group and URL tag.
- use various macros (%%{_mandir}, %%{_infodir}).
- install %%doc files.
- run `make check.'
* Tue Sep 21 1999 schwab@suse.de
- Preserve file permissions
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Mon Jul 19 1999 florian@suse.de
- update to recode 3.5
